/*******************************************************************************
* File Name: SysTickCLK.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_SysTickCLK_H)
#define CY_CLOCK_SysTickCLK_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/
#if defined CYREG_PERI_DIV_CMD

void SysTickCLK_StartEx(uint32 alignClkDiv);
#define SysTickCLK_Start() \
    SysTickCLK_StartEx(SysTickCLK__PA_DIV_ID)

#else

void SysTickCLK_Start(void);

#endif/* CYREG_PERI_DIV_CMD */

void SysTickCLK_Stop(void);

void SysTickCLK_SetFractionalDividerRegister(uint16 clkDivider, uint8 clkFractional);

uint16 SysTickCLK_GetDividerRegister(void);
uint8  SysTickCLK_GetFractionalDividerRegister(void);

#define SysTickCLK_Enable()                         SysTickCLK_Start()
#define SysTickCLK_Disable()                        SysTickCLK_Stop()
#define SysTickCLK_SetDividerRegister(clkDivider, reset)  \
    SysTickCLK_SetFractionalDividerRegister((clkDivider), 0u)
#define SysTickCLK_SetDivider(clkDivider)           SysTickCLK_SetDividerRegister((clkDivider), 1u)
#define SysTickCLK_SetDividerValue(clkDivider)      SysTickCLK_SetDividerRegister((clkDivider) - 1u, 1u)


/***************************************
*             Registers
***************************************/
#if defined CYREG_PERI_DIV_CMD

#define SysTickCLK_DIV_ID     SysTickCLK__DIV_ID

#define SysTickCLK_CMD_REG    (*(reg32 *)CYREG_PERI_DIV_CMD)
#define SysTickCLK_CTRL_REG   (*(reg32 *)SysTickCLK__CTRL_REGISTER)
#define SysTickCLK_DIV_REG    (*(reg32 *)SysTickCLK__DIV_REGISTER)

#define SysTickCLK_CMD_DIV_SHIFT          (0u)
#define SysTickCLK_CMD_PA_DIV_SHIFT       (8u)
#define SysTickCLK_CMD_DISABLE_SHIFT      (30u)
#define SysTickCLK_CMD_ENABLE_SHIFT       (31u)

#define SysTickCLK_CMD_DISABLE_MASK       ((uint32)((uint32)1u << SysTickCLK_CMD_DISABLE_SHIFT))
#define SysTickCLK_CMD_ENABLE_MASK        ((uint32)((uint32)1u << SysTickCLK_CMD_ENABLE_SHIFT))

#define SysTickCLK_DIV_FRAC_MASK  (0x000000F8u)
#define SysTickCLK_DIV_FRAC_SHIFT (3u)
#define SysTickCLK_DIV_INT_MASK   (0xFFFFFF00u)
#define SysTickCLK_DIV_INT_SHIFT  (8u)

#else 

#define SysTickCLK_DIV_REG        (*(reg32 *)SysTickCLK__REGISTER)
#define SysTickCLK_ENABLE_REG     SysTickCLK_DIV_REG
#define SysTickCLK_DIV_FRAC_MASK  SysTickCLK__FRAC_MASK
#define SysTickCLK_DIV_FRAC_SHIFT (16u)
#define SysTickCLK_DIV_INT_MASK   SysTickCLK__DIVIDER_MASK
#define SysTickCLK_DIV_INT_SHIFT  (0u)

#endif/* CYREG_PERI_DIV_CMD */

#endif /* !defined(CY_CLOCK_SysTickCLK_H) */

/* [] END OF FILE */
